==> pulumi-azure-native-kotlin-2.19.0.0-sources.jar: com/pulumi/azurenative/dbformariadb/kotlin/inputs/ServerPropertiesForReplicaArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.dbformariadb.kotlin.inputs

import com.pulumi.azurenative.dbformariadb.inputs.ServerPropertiesForReplicaArgs.builder
import com.pulumi.azurenative.dbformariadb.kotlin.enums.MinimalTlsVersionEnum
import com.pulumi.azurenative.dbformariadb.kotlin.enums.PublicNetworkAccessEnum
import com.pulumi.azurenative.dbformariadb.kotlin.enums.ServerVersion
import com.pulumi.azurenative.dbformariadb.kotlin.enums.SslEnforcementEnum
import com.pulumi.core.Either
import com.pulumi.core.Output
import com.pulumi.core.Output.of
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiNullFieldException
import com.pulumi.kotlin.PulumiTagMarker
import com.pulumi.kotlin.applySuspend
import kotlin.String
import kotlin.Suppress
import kotlin.Unit
import kotlin.jvm.JvmName

/**
 * The properties to create a new replica.
 * @property createMode The mode to create a new server.
 * Expected value is 'Replica'.
 * @property minimalTlsVersion Enforce a minimal Tls version for the server.
 * @property publicNetworkAccess Whether or not public network access is allowed for this server. Value is optional but if passed in, must be 'Enabled' or 'Disabled'
 * @property sourceServerId The master server id to create replica from.
 * @property sslEnforcement Enable ssl enforcement or not when connect to server.
 * @property storageProfile Storage profile of a server.
 * @property version Server version.
 */
public data class ServerPropertiesForReplicaArgs(
    public val createMode: Output<String>,
    public val minimalTlsVersion: Output<Either<String, MinimalTlsVersionEnum>>? = null,
    public val publicNetworkAccess: Output<Either<String, PublicNetworkAccessEnum>>? = null,
    public val sourceServerId: Output<String>,
    public val sslEnforcement: Output<SslEnforcementEnum>? = null,
    public val storageProfile: Output<StorageProfileArgs>? = null,
    public val version: Output<Either<String, ServerVersion>>? = null,
) : ConvertibleToJava<com.pulumi.azurenative.dbformariadb.inputs.ServerPropertiesForReplicaArgs> {
    override fun toJava(): com.pulumi.azurenative.dbformariadb.inputs.ServerPropertiesForReplicaArgs =
        com.pulumi.azurenative.dbformariadb.inputs.ServerPropertiesForReplicaArgs.builder()
            .createMode(createMode.applyValue({ args0 -> args0 }))
            .minimalTlsVersion(
                minimalTlsVersion?.applyValue({ args0 ->
                    args0.transform(
                        { args0 -> args0 },
                        { args0 -> args0.let({ args0 -> args0.toJava() }) },
                    )
                }),
            )
            .publicNetworkAccess(
                publicNetworkAccess?.applyValue({ args0 ->
                    args0.transform(
                        { args0 -> args0 },
                        { args0 -> args0.let({ args0 -> args0.toJava() }) },
                    )
                }),
            )
            .sourceServerId(sourceServerId.applyValue({ args0 -> args0 }))
            .sslEnforcement(sslEnforcement?.applyValue({ args0 -> args0.let({ args0 -> args0.toJava() }) }))
            .storageProfile(storageProfile?.applyValue({ args0 -> args0.let({ args0 -> args0.toJava() }) }))
            .version(
                version?.applyValue({ args0 ->
                    args0.transform({ args0 -> args0 }, { args0 ->
                        args0.let({ args0 -> args0.toJava() })
                    })
                }),
            ).build()
}

/**
 * Builder for [ServerPropertiesForReplicaArgs].
 */
@PulumiTagMarker
public class ServerPropertiesForReplicaArgsBuilder internal constructor() {
    private var createMode: Output<String>? = null

    private var minimalTlsVersion: Output<Either<String, MinimalTlsVersionEnum>>? = null

    private var publicNetworkAccess: Output<Either<String, PublicNetworkAccessEnum>>? = null

    private var sourceServerId: Output<String>? = null

    private var sslEnforcement: Output<SslEnforcementEnum>? = null

    private var storageProfile: Output<StorageProfileArgs>? = null

    private var version: Output<Either<String, ServerVersion>>? = null

    /**
     * @param value The mode to create a new server.
     * Expected value is 'Replica'.
     */
    @JvmName("irmacmxkdadpfcdr")
    public suspend fun createMode(`value`: Output<String>) {
        this.createMode = value
    }

    /**
     * @param value Enforce a minimal Tls version for the server.
     */
    @JvmName("xsxvsanonsplfthb")
    public suspend fun minimalTlsVersion(`value`: Output<Either<String, MinimalTlsVersionEnum>>) {
        this.minimalTlsVersion = value
    }

    /**
     * @param value Whether or not public network access is allowed for this server. Value is optional but if passed in, must be 'Enabled' or 'Disabled'
     */
    @JvmName("ujstvsnfsgwbvxdq")
    public suspend fun publicNetworkAccess(`value`: Output<Either<String, PublicNetworkAccessEnum>>) {
        this.publicNetworkAccess = value
    }

    /**
     * @param value The master server id to create replica from.
     */
    @JvmName("lpxrsjgybhcmknjq")
    public suspend fun sourceServerId(`value`: Output<String>) {
        this.sourceServerId = value
    }

    /**
     * @param value Enable ssl enforcement or not when connect to server.
     */
    @JvmName("gkgepshwbicgeboh")
    public suspend fun sslEnforcement(`value`: Output<SslEnforcementEnum>) {
        this.sslEnforcement = value
    }

    /**
     * @param value Storage profile of a server.
     */
    @JvmName("btpepechgkmrrtqy")
    public suspend fun storageProfile(`value`: Output<StorageProfileArgs>) {
        this.storageProfile = value
    }

    /**
     * @param value Server version.
     */
    @JvmName("csieyebnjuweckjn")
    public suspend fun version(`value`: Output<Either<String, ServerVersion>>) {
        this.version = value
    }

    /**
     * @param value The mode to create a new server.
     * Expected value is 'Replica'.
     */
    @JvmName("qpvhgkpxaihoyncx")
    public suspend fun createMode(`value`: String) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.createMode = mapped
    }

    /**
     * @param value Enforce a minimal Tls version for the server.
     */
    @JvmName("auovyrowxvrhyhlf")
    public suspend fun minimalTlsVersion(`value`: Either<String, MinimalTlsVersionEnum>?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.minimalTlsVersion = mapped
    }

    /**
     * @param value Enforce a minimal Tls version for the server.
     */
    @JvmName("mlcmnhtgvigvlcej")
    public fun minimalTlsVersion(`value`: String) {
        val toBeMapped = Either.ofLeft<String, MinimalTlsVersionEnum>(value)
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.minimalTlsVersion = mapped
    }

    /**
     * @param value Enforce a minimal Tls version for the server.
     */
    @JvmName("xiysmeipgytcvlkv")
    public fun minimalTlsVersion(`value`: MinimalTlsVersionEnum) {
        val toBeMapped = Either.ofRight<String, MinimalTlsVersionEnum>(value)
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.minimalTlsVersion = mapped
    }

    /**
     * @param value Whether or not public network access is allowed for this server. Value is optional but if passed in, must be 'Enabled' or 'Disabled'
     */
    @JvmName("pslnsobvdrstbhqq")
    public suspend fun publicNetworkAccess(`value`: Either<String, PublicNetworkAccessEnum>?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.publicNetworkAccess = mapped
    }

    /**
     * @param value Whether or not public network access is allowed for this server. Value is optional but if passed in, must be 'Enabled' or 'Disabled'
     */
    @JvmName("gigrihpklnaskpyi")
    public fun publicNetworkAccess(`value`: String) {
        val toBeMapped = Either.ofLeft<String, PublicNetworkAccessEnum>(value)
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.publicNetworkAccess = mapped
    }

    /**
     * @param value Whether or not public network access is allowed for this server. Value is optional but if passed in, must be 'Enabled' or 'Disabled'
     */
    @JvmName("qnrayoylrxdmsern")
    public fun publicNetworkAccess(`value`: PublicNetworkAccessEnum) {
        val toBeMapped = Either.ofRight<String, PublicNetworkAccessEnum>(value)
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.publicNetworkAccess = mapped
    }

    /**
     * @param value The master server id to create replica from.
     */
    @JvmName("yymnhddsxfocnnpm")
    public suspend fun sourceServerId(`value`: String) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.sourceServerId = mapped
    }

    /**
     * @param value Enable ssl enforcement or not when connect to server.
     */
    @JvmName("mlkvucwrpwjfdrro")
    public suspend fun sslEnforcement(`value`: SslEnforcementEnum?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.sslEnforcement = mapped
    }

    /**
     * @param value Storage profile of a server.
     */
    @JvmName("kasxcwbofjhndohd")
    public suspend fun storageProfile(`value`: StorageProfileArgs?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.storageProfile = mapped
    }

    /**
     * @param argument Storage profile of a server.
     */
    @JvmName("wbrlgxtxaammpyye")
    public suspend fun storageProfile(argument: suspend StorageProfileArgsBuilder.() -> Unit) {
        val toBeMapped = StorageProfileArgsBuilder().applySuspend { argument() }.build()
        val mapped = of(toBeMapped)
        this.storageProfile = mapped
    }

    /**
     * @param value Server version.
     */
    @JvmName("ypxwxwnpsnilltgw")
    public suspend fun version(`value`: Either<String, ServerVersion>?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.version = mapped
    }

    /**
     * @param value Server version.
     */
    @JvmName("jkneitvuklgftxhx")
    public fun version(`value`: String) {
        val toBeMapped = Either.ofLeft<String, ServerVersion>(value)
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.version = mapped
    }

    /**
     * @param value Server version.
     */
    @JvmName("anurvypfsqwxpwad")
    public fun version(`value`: ServerVersion) {
        val toBeMapped = Either.ofRight<String, ServerVersion>(value)
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.version = mapped
    }

    internal fun build(): ServerPropertiesForReplicaArgs = ServerPropertiesForReplicaArgs(
        createMode = createMode ?: throw PulumiNullFieldException("createMode"),
        minimalTlsVersion = minimalTlsVersion,
        publicNetworkAccess = publicNetworkAccess,
        sourceServerId = sourceServerId ?: throw PulumiNullFieldException("sourceServerId"),
        sslEnforcement = sslEnforcement,
        storageProfile = storageProfile,
        version = version,
    )
}

==> pulumi-azure-native-kotlin-2.28.0.0-sources.jar: com/pulumi/azurenative/dbformariadb/kotlin/inputs/ServerPropertiesForReplicaArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.dbformariadb.kotlin.inputs

import com.pulumi.azurenative.dbformariadb.inputs.ServerPropertiesForReplicaArgs.builder
import com.pulumi.azurenative.dbformariadb.kotlin.enums.MinimalTlsVersionEnum
import com.pulumi.azurenative.dbformariadb.kotlin.enums.PublicNetworkAccessEnum
import com.pulumi.azurenative.dbformariadb.kotlin.enums.ServerVersion
import com.pulumi.azurenative.dbformariadb.kotlin.enums.SslEnforcementEnum
import com.pulumi.core.Either
import com.pulumi.core.Output
import com.pulumi.core.Output.of
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiNullFieldException
import com.pulumi.kotlin.PulumiTagMarker
import com.pulumi.kotlin.applySuspend
import kotlin.String
import kotlin.Suppress
import kotlin.Unit
import kotlin.jvm.JvmName

/**
 * The properties to create a new replica.
 * @property createMode The mode to create a new server.
 * Expected value is 'Replica'.
 * @property minimalTlsVersion Enforce a minimal Tls version for the server.
 * @property publicNetworkAccess Whether or not public network access is allowed for this server. Value is optional but if passed in, must be 'Enabled' or 'Disabled'
 * @property sourceServerId The master server id to create replica from.
 * @property sslEnforcement Enable ssl enforcement or not when connect to server.
 * @property storageProfile Storage profile of a server.
 * @property version Server version.
 */
public data class ServerPropertiesForReplicaArgs(
    public val createMode: Output<String>,
    public val minimalTlsVersion: Output<Either<String, MinimalTlsVersionEnum>>? = null,
    public val publicNetworkAccess: Output<Either<String, PublicNetworkAccessEnum>>? = null,
    public val sourceServerId: Output<String>,
    public val sslEnforcement: Output<SslEnforcementEnum>? = null,
    public val storageProfile: Output<StorageProfileArgs>? = null,
    public val version: Output<Either<String, ServerVersion>>? = null,
) : ConvertibleToJava<com.pulumi.azurenative.dbformariadb.inputs.ServerPropertiesForReplicaArgs> {
    override fun toJava(): com.pulumi.azurenative.dbformariadb.inputs.ServerPropertiesForReplicaArgs =
        com.pulumi.azurenative.dbformariadb.inputs.ServerPropertiesForReplicaArgs.builder()
            .createMode(createMode.applyValue({ args0 -> args0 }))
            .minimalTlsVersion(
                minimalTlsVersion?.applyValue({ args0 ->
                    args0.transform(
                        { args0 -> args0 },
                        { args0 -> args0.let({ args0 -> args0.toJava() }) },
                    )
                }),
            )
            .publicNetworkAccess(
                publicNetworkAccess?.applyValue({ args0 ->
                    args0.transform(
                        { args0 -> args0 },
                        { args0 -> args0.let({ args0 -> args0.toJava() }) },
                    )
                }),
            )
            .sourceServerId(sourceServerId.applyValue({ args0 -> args0 }))
            .sslEnforcement(sslEnforcement?.applyValue({ args0 -> args0.let({ args0 -> args0.toJava() }) }))
            .storageProfile(storageProfile?.applyValue({ args0 -> args0.let({ args0 -> args0.toJava() }) }))
            .version(
                version?.applyValue({ args0 ->
                    args0.transform({ args0 -> args0 }, { args0 ->
                        args0.let({ args0 -> args0.toJava() })
                    })
                }),
            ).build()
}

/**
 * Builder for [ServerPropertiesForReplicaArgs].
 */
@PulumiTagMarker
public class ServerPropertiesForReplicaArgsBuilder internal constructor() {
    private var createMode: Output<String>? = null

    private var minimalTlsVersion: Output<Either<String, MinimalTlsVersionEnum>>? = null

    private var publicNetworkAccess: Output<Either<String, PublicNetworkAccessEnum>>? = null

    private var sourceServerId: Output<String>? = null

    private var sslEnforcement: Output<SslEnforcementEnum>? = null

    private var storageProfile: Output<StorageProfileArgs>? = null

    private var version: Output<Either<String, ServerVersion>>? = null

    /**
     * @param value The mode to create a new server.
     * Expected value is 'Replica'.
     */
    @JvmName("adfbunsivefufigc")
    public suspend fun createMode(`value`: Output<String>) {
        this.createMode = value
    }

    /**
     * @param value Enforce a minimal Tls version for the server.
     */
    @JvmName("oecekejpepxhrcml")
    public suspend fun minimalTlsVersion(`value`: Output<Either<String, MinimalTlsVersionEnum>>) {
        this.minimalTlsVersion = value
    }

    /**
     * @param value Whether or not public network access is allowed for this server. Value is optional but if passed in, must be 'Enabled' or 'Disabled'
     */
    @JvmName("leqkruayblrrysms")
    public suspend fun publicNetworkAccess(`value`: Output<Either<String, PublicNetworkAccessEnum>>) {
        this.publicNetworkAccess = value
    }

    /**
     * @param value The master server id to create replica from.
     */
    @JvmName("nruemckkgvbsyjnh")
    public suspend fun sourceServerId(`value`: Output<String>) {
        this.sourceServerId = value
    }

    /**
     * @param value Enable ssl enforcement or not when connect to server.
     */
    @JvmName("mvbjrgxxqeslqhjm")
    public suspend fun sslEnforcement(`value`: Output<SslEnforcementEnum>) {
        this.sslEnforcement = value
    }

    /**
     * @param value Storage profile of a server.
     */
    @JvmName("sjqbvsttuutfoyim")
    public suspend fun storageProfile(`value`: Output<StorageProfileArgs>) {
        this.storageProfile = value
    }

    /**
     * @param value Server version.
     */
    @JvmName("qrefgreojmmlrrpd")
    public suspend fun version(`value`: Output<Either<String, ServerVersion>>) {
        this.version = value
    }

    /**
     * @param value The mode to create a new server.
     * Expected value is 'Replica'.
     */
    @JvmName("bstencfdwrhweiem")
    public suspend fun createMode(`value`: String) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.createMode = mapped
    }

    /**
     * @param value Enforce a minimal Tls version for the server.
     */
    @JvmName("jmepxpocgtwlwome")
    public suspend fun minimalTlsVersion(`value`: Either<String, MinimalTlsVersionEnum>?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.minimalTlsVersion = mapped
    }

    /**
     * @param value Enforce a minimal Tls version for the server.
     */
    @JvmName("fnspotxhwjnugixc")
    public fun minimalTlsVersion(`value`: String) {
        val toBeMapped = Either.ofLeft<String, MinimalTlsVersionEnum>(value)
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.minimalTlsVersion = mapped
    }

    /**
     * @param value Enforce a minimal Tls version for the server.
     */
    @JvmName("mjptacpiiclfaiba")
    public fun minimalTlsVersion(`value`: MinimalTlsVersionEnum) {
        val toBeMapped = Either.ofRight<String, MinimalTlsVersionEnum>(value)
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.minimalTlsVersion = mapped
    }

    /**
     * @param value Whether or not public network access is allowed for this server. Value is optional but if passed in, must be 'Enabled' or 'Disabled'
     */
    @JvmName("mfekdgfiblebqtac")
    public suspend fun publicNetworkAccess(`value`: Either<String, PublicNetworkAccessEnum>?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.publicNetworkAccess = mapped
    }

    /**
     * @param value Whether or not public network access is allowed for this server. Value is optional but if passed in, must be 'Enabled' or 'Disabled'
     */
    @JvmName("hohxhxswmpsdysic")
    public fun publicNetworkAccess(`value`: String) {
        val toBeMapped = Either.ofLeft<String, PublicNetworkAccessEnum>(value)
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.publicNetworkAccess = mapped
    }

    /**
     * @param value Whether or not public network access is allowed for this server. Value is optional but if passed in, must be 'Enabled' or 'Disabled'
     */
    @JvmName("wfxqddbrtwcytxhe")
    public fun publicNetworkAccess(`value`: PublicNetworkAccessEnum) {
        val toBeMapped = Either.ofRight<String, PublicNetworkAccessEnum>(value)
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.publicNetworkAccess = mapped
    }

    /**
     * @param value The master server id to create replica from.
     */
    @JvmName("kotspdvbpyxbqloi")
    public suspend fun sourceServerId(`value`: String) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.sourceServerId = mapped
    }

    /**
     * @param value Enable ssl enforcement or not when connect to server.
     */
    @JvmName("gcrgsaaxtyendnpw")
    public suspend fun sslEnforcement(`value`: SslEnforcementEnum?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.sslEnforcement = mapped
    }

    /**
     * @param value Storage profile of a server.
     */
    @JvmName("djqsvysgmucnegmg")
    public suspend fun storageProfile(`value`: StorageProfileArgs?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.storageProfile = mapped
    }

    /**
     * @param argument Storage profile of a server.
     */
    @JvmName("qpynubldjigtxkew")
    public suspend fun storageProfile(argument: suspend StorageProfileArgsBuilder.() -> Unit) {
        val toBeMapped = StorageProfileArgsBuilder().applySuspend { argument() }.build()
        val mapped = of(toBeMapped)
        this.storageProfile = mapped
    }

    /**
     * @param value Server version.
     */
    @JvmName("wrgmkjqcppvehwqj")
    public suspend fun version(`value`: Either<String, ServerVersion>?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.version = mapped
    }

    /**
     * @param value Server version.
     */
    @JvmName("dpyhrckheymvifti")
    public fun version(`value`: String) {
        val toBeMapped = Either.ofLeft<String, ServerVersion>(value)
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.version = mapped
    }

    /**
     * @param value Server version.
     */
    @JvmName("gqpydlvcrmquwitl")
    public fun version(`value`: ServerVersion) {
        val toBeMapped = Either.ofRight<String, ServerVersion>(value)
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.version = mapped
    }

    internal fun build(): ServerPropertiesForReplicaArgs = ServerPropertiesForReplicaArgs(
        createMode = createMode ?: throw PulumiNullFieldException("createMode"),
        minimalTlsVersion = minimalTlsVersion,
        publicNetworkAccess = publicNetworkAccess,
        sourceServerId = sourceServerId ?: throw PulumiNullFieldException("sourceServerId"),
        sslEnforcement = sslEnforcement,
        storageProfile = storageProfile,
        version = version,
    )
}
